@@ -1,12 +1,11 @@
 package DBIx::Class::DeploymentHandler::Dad;
-$DBIx::Class::DeploymentHandler::Dad::VERSION = '0.002224';
+$DBIx::Class::DeploymentHandler::Dad::VERSION = '0.002225';
 # ABSTRACT: Parent class for DeploymentHandlers
 
-use Moose;
-require DBIx::Class::Schema;    # loaded for type constraint
+use Moo;
 use Carp::Clan '^DBIx::Class::DeploymentHandler';
 use DBIx::Class::DeploymentHandler::LogImporter ':log';
-use DBIx::Class::DeploymentHandler::Types;
+use DBIx::Class::DeploymentHandler::Types -all;
 
 has schema => (
   is       => 'ro',
@@ -14,25 +13,23 @@ has schema => (
 );
 
 has backup_directory => (
-  isa => 'Str',
+  isa => Str,
   is  => 'ro',
   predicate  => 'has_backup_directory',
 );
 
 has to_version => (
-  is         => 'ro',
-  isa        => 'Str',
-  lazy_build => 1,
+  is         => 'lazy',
+  isa        => VersionNonObj,
+  coerce     => 1,
 );
 
-sub _build_to_version {
-  my $version = $_[0]->schema_version;
-  ref($version) ? $version->numify : $version;
-}
+sub _build_to_version { $_[0]->schema_version }
 
 has schema_version => (
-  is         => 'ro',
-  lazy_build => 1,
+  is         => 'lazy',
+  isa        => VersionNonObj,
+  coerce     => 1,
 );
 
 sub _build_schema_version { $_[0]->schema->schema_version }
