@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::HandlesVersionStorage;
-$DBIx::Class::DeploymentHandler::HandlesVersionStorage::VERSION = '0.002224';
-use Moose::Role;
+$DBIx::Class::DeploymentHandler::HandlesVersionStorage::VERSION = '0.002225';
+use Moo::Role;
 
 # ABSTRACT: Interface for version storage methods
 
