@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::HandlesVersioning;
-$DBIx::Class::DeploymentHandler::HandlesVersioning::VERSION = '0.002224';
-use Moose::Role;
+$DBIx::Class::DeploymentHandler::HandlesVersioning::VERSION = '0.002225';
+use Moo::Role;
 
 # ABSTRACT: Interface for version methods
 
