@@ -1,26 +1,31 @@
 package DBIx::Class::DeploymentHandler::Types;
-$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002224';
+$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002225';
 use strict;
 use warnings;
+use IO::All;
 
 # ABSTRACT: Types internal to DBIx::Class::DeploymentHandler
 
-use Moose::Util::TypeConstraints;
-subtype 'DBIx::Class::DeploymentHandler::Databases'
- => as 'ArrayRef[Str]';
+use Type::Library
+  -base,
+  -declare => qw( Databases VersionNonObj DirObject );
+use Type::Utils -all;
+BEGIN { extends "Types::Standard" };
 
-coerce 'DBIx::Class::DeploymentHandler::Databases'
- => from 'Str'
- => via { [$_] };
+declare Databases, as ArrayRef[Str];
 
-subtype 'DBIx::Class::DeploymentHandler::VersionNonObj'
- => as 'Str';
+coerce Databases,
+  from Str, via { [ $_ ] };
 
-coerce 'DBIx::Class::DeploymentHandler::VersionNonObj'
- => from 'Object'
- => via { $_->numify };
+declare VersionNonObj, as Str;
+
+coerce VersionNonObj,
+  from InstanceOf['version'], via { $_->numify };
+
+declare DirObject, as InstanceOf['IO::All::Dir'];
+coerce DirObject,
+  from Str, via { io->dir($_) };
 
-no Moose::Util::TypeConstraints;
 1;
 
 # vim: ts=2 sw=2 expandtab
