@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::WithReasonableDefaults;
-$DBIx::Class::DeploymentHandler::WithReasonableDefaults::VERSION = '0.002224';
-use Moose::Role;
+$DBIx::Class::DeploymentHandler::WithReasonableDefaults::VERSION = '0.002225';
+use Moo::Role;
 
 # ABSTRACT: Make default arguments to a few methods sensible
 
